<?php
/**
 * Accesspress Parallax Blog
 *
 * @package    Accesspress Themes
 * @subpackage Accesspress Parallax
 * @since      version 2.0.1
 */

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	return; // Exit if it is accessed directly
}

class Parallax_Slider_Elementor_Section extends Widget_Base {
    use \Elementor\parallax_blog_Functions;

	/**
	 * Retrieve parallax_blog_Blog widget name.
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'pb-slider';
	}

	/**
	 * Retrieve parallax_blog_Blog widget title.
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Parallax Blog: Slider', 'accesspress-parallax' );
	}

	/**
	 * Retrieve parallax_blog_Blog widget icon.
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-grid';
	}

	/**
	 * Retrieve the list of categories the parallax_blog_Blog widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'parallax-blog-widget-blocks' );
	}

	/**
	 * Register parallax_blog_Blog widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @access protected
	 */
	protected function _register_controls() {

        // Widget title section
        $this->start_controls_section(
            'section_detail',
            array(
                'label' => esc_html__( 'Section Setting', 'accesspress-parallax' ),
            )
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'              => 'image_size',
                'label'             => esc_html__( 'Image Size', 'accesspress-parallax' ),
                'default'           => 'blog-thumbnail',
                
            ]
        );
        $this->add_control(
            'post_meta',
            [
                'label'             => esc_html__( 'Show date', 'accesspress-parallax' ),
                'type'              => Controls_Manager::SWITCHER,
                'default'           => 'yes',
                'label_on'          => esc_html__( 'Yes', 'accesspress-parallax' ),
                'label_off'         => esc_html__( 'No', 'accesspress-parallax' ),
                'return_value'      => 'yes',
            ]
        ); 

        $this->add_control(
            'show_cat',
            [
                'label'             => esc_html__( 'Show Categories', 'accesspress-parallax' ),
                'type'              => Controls_Manager::SWITCHER,
                'default'           => 'yes',
                'label_on'          => esc_html__( 'Yes', 'accesspress-parallax' ),
                'label_off'         => esc_html__( 'No', 'accesspress-parallax' ),
                'return_value'      => 'yes',
            ]
        );   

        $this->add_control(
            'show_author',
            [
                'label'             => esc_html__( 'Show Author', 'accesspress-parallax' ),
                'type'              => Controls_Manager::SWITCHER,
                'default'           => 'yes',
                'label_on'          => esc_html__( 'Yes', 'accesspress-parallax' ),
                'label_off'         => esc_html__( 'No', 'accesspress-parallax' ),
                'return_value'      => 'yes',
            ]
        );   
        
        $this->end_controls_section();

        $this->query_controls();

        $this->post_excerpts( array( 'content_excerpts' => true, 'readmore' => true ));

        //styling tab
        $this->start_controls_section(
            'section_general_style',
            [
                'label' => esc_html__( 'General Styles', 'accesspress-parallax' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'content_date_color',
            [
                'label'     => esc_html__( 'Date Color', 'accesspress-parallax' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .posted-date' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'content_title_color',
            [
                'label'     => esc_html__( 'Content Title Color', 'accesspress-parallax' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} h4.blog-post-title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        //element title
        $this->add_control(
            'content_title_color_hover',
            [
                'label'     => esc_html__( 'Content Title Color: Hover', 'accesspress-parallax' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} h4.blog-post-title a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'content_description_color',
            [
                'label'     => esc_html__( 'Content Description Color', 'accesspress-parallax' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .blog-excerpt' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'content_button_color',
            [
                'label'     => esc_html__( 'Author Color', 'accesspress-parallax' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slider-author' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'content_date_typography',
                'label'     => esc_html__( 'Date Typography', 'accesspress-parallax' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} .posted-date',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'content_title_typography',
                'label'     => esc_html__( 'Content Title Typography', 'accesspress-parallax' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} h4.blog-post-title',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'content_excerpt_typography',
                'label'     => esc_html__( 'Content Description Typography', 'accesspress-parallax' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} .blog-excerpt',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'pb_author',
                'label'     => esc_html__( 'Author Typography', 'accesspress-parallax' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} .slider-author',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'content_button_typography',
                'label'     => esc_html__( 'Button Typography', 'accesspress-parallax' ),
                'scheme'    => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} .blog-readmore',
            ]
        );


        $this->end_controls_section();//end for styling tab
	}
	/**
	 * Render parallax_blog_Blog widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings();

        $this->add_render_attribute( 'pb-slider', 'class', 'pb-slider-section' );
        $date       = isset( $settings[ 'post_meta' ] )? $settings[ 'post_meta' ] : '';
        $show_cat   = isset( $settings[ 'show_cat' ] )? $settings[ 'show_cat' ] : '';
        $show_author   = isset( $settings[ 'show_author' ] )? $settings[ 'show_author' ] : '';
        $showposts  = isset( $settings[ 'showposts' ] )? $settings[ 'showposts' ] : '';
        $excerpt    = isset( $settings[ 'content_excerpts' ] )? $settings[ 'content_excerpts' ] : 200;
        $readmore   = isset( $settings[ 'readmore' ] )? $settings[ 'readmore' ] : esc_html__('Read More', 'accesspress-parallax');
        $block_args = parallax_blog_query($settings,$first_id='', $showposts );
        $query = new \WP_Query( $block_args );
        ?>
        <div <?php echo $this->get_render_attribute_string( 'pb-slider' ); ?>>
            <div class=" pb-slider-wrapper owl-carousel">
                <?php 
                if ( $query->have_posts() ):
                    while ( $query->have_posts() ): $query->the_post();
                        ?>
                        <div class="pb-slider-wrap">
                            <div class="slider-image">
                                <?php
                                if ( has_post_thumbnail() ) :
                                    $image_id = '';
                                    $img_src    = '';
                                    $image_id = get_post_thumbnail_id();   
                                    if( $image_id ){
                                        $img_src    = Group_Control_Image_Size::get_attachment_image_src( $image_id, 'image_size', $settings );
                                    }
                                    ?>
                                    <img src="<?php echo esc_url( $img_src ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
                                <?php else: ?>
                                    <img src="<?php echo esc_url( get_template_directory_uri() . '/images/no-image.jpg' ) ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
                                <?php endif; ?>
                            </div>
                            <div class="slider-content">
                                <?php if($show_cat): ?>
                                <div class="slider-cat">
                                    <?php  the_category(); ?>
                                </div>
                                <?php endif;?>
                                <div>
                                    <?php 
                                    the_title('<h4 class="blog-post-title"><a href="'. get_the_permalink().'">', '</a></h4>'); ?>
                                </div>
                                <div class="blog-excerpt">
                                    <?php echo accesspress_letter_count( get_the_excerpt(), $excerpt );  // WPCS: XSS OK.   ?> 
                                </div>
                               <div class="author-wrapper">
                                    <div class = "blog-avatar">
                                        <?php echo get_avatar( get_the_author_meta( 'ID' ), 55 ); ?>
                                    </div>

                                    <div class="pb-auth-wrap">
                                        <?php if($show_author): ?>
                                            <div class="slider-author author"><?php echo esc_attr(get_the_author()); ?></div> 
                                        <?php endif; ?>
                                        <?php if($date): ?>
                                            <span class="posted-date"><?php echo esc_html(get_the_date('d M Y')); ?></span>
                                        <?php 
                                        endif;?>
                                    </div> 
                                </div>
                            </div>
                        </div>
                        <?php
                    endwhile;
                    wp_reset_postdata();
                endif;?>
            </div>
        </div><!-- element main wrapper -->
<?php
	}
}